Clojure only.

io.triplox.types

Conversion between Triplox wire types and Clojure types.

Conversion between Triplox wire types and Clojure types.
raw docstring

wire->cljclj

(wire->clj v)

Convert a wire protocol value to an idiomatic Clojure value. TreeMap<String,Object> → Clojure map with keyword keys. TaggedTuple → vector (same as Vector for Clojure consumers). Most types pass through unchanged.

Convert a wire protocol value to an idiomatic Clojure value.
TreeMap<String,Object> → Clojure map with keyword keys.
TaggedTuple → vector (same as Vector for Clojure consumers).
Most types pass through unchanged.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries