Clojure only.

xyz.triplox.types

Conversion between Triplox wire types and Clojure types.

Conversion between Triplox wire types and Clojure types.
raw docstring

delta->cljclj

(delta->clj delta)
source

wire->cljclj

(wire->clj v)

Convert a wire protocol value to an idiomatic Clojure value. TreeMap<String,Object> → Clojure map with keyword keys. Most types pass through unchanged.

Convert a wire protocol value to an idiomatic Clojure value.
TreeMap<String,Object> → Clojure map with keyword keys.
Most types pass through unchanged.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries