Clojure only.

xyz.triplox.view

EXPERIMENTAL: Client-side materialized views backed by incremental query subscriptions. This namespace may change or be removed without notice.

EXPERIMENTAL: Client-side materialized views backed by incremental query
subscriptions. This namespace may change or be removed without notice.
raw docstring

->viewclj

(->view conn query)

Create a client-side materialized view for an incremental query.

Returns a Closeable View. Close it to stop the worker and unsubscribe.

Create a client-side materialized view for an incremental query.

Returns a Closeable View. Close it to stop the worker and unsubscribe.
sourceraw docstring

get-viewclj

(get-view {:keys [view]})

Return the current rows in a materialized view.

Return the current rows in a materialized view.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries